Handbook - Reproductive System Overview
Description: WormAtlas: A database of behavioral and structural anatomy of Caenorhabditis elegans.
Keywords: Caenorhabditis, elegans, anatomy, hermaphrodite, worm, nematode

Home Handbooks Hermaphrodite Male Dauer Embryo Aging P. pacificus S. stercoralis Resources WormImage Slidable Worm WormWiring Hall Lab Anatomical Methods Glossary of Terms Movie Gallery Individual Neurons Neurons & Circuits Worm Literature Cell Identification Cell Lineages Cell List Sperm Gallery Digital Development DIC PharynxAtlas User Guides Abbreviations Color Codes Copyright and Use How to Cite Links WormBase WormBook CGC WormGUIDES CytoSHOW OpenWorm Nemanode CeNGEN C. elegans Natural Diversity Anatomy by DIC - by J. Yochem About Us Mission Statement Contact

REPRODUCTIVE SYSTEM OVERVIEW Click pictures for new window with figure and legend, click again for high resolution image
1 General Description The reproductive system is one of the most sexually dimorphic tissues in the animal, with many components differing between hermaphrodites and males (see Introduction for an overview of the male anatomy). The hermaphrodite reproductive system produces mature gametes and provides the structure and environment for fertilization and egg-laying (ReproFIG 1). It can be divided into three major parts: the somatic gonad (described in Reproduction System - Somatic Gonad), the germ line (Reproductive System - Germ Line), and the egg-laying apparatus (Reproductive System - Egg-laying Apparatus) (ReproTABLE 1). The somatic gonad and germ line together form two symmetrical U-shaped tubes (arms) that are joined to a common uterus and egg-laying apparatus in the midbody. ReproFIG 1: The adult hermaphrodite reproductive system. (Top) Adult hermaphrodite, lateral view, left side, showing the location of the reproductive system within an intact animal. The reproductive system has twofold symmetry and consists of two U-shaped gonad arms joined to a common uterus. The reproductive system opens to the environment via the vulva, located in the ventral midbody. (Bottom) One half of the reproductive system, enlarged and separated from other body parts. (DTC) Distal tip cell; (DG) distal gonad; (PG) proximal gonad; (Sp) spermatheca; (Sp-ut) spermathecal-uterine valve; VC1-6 and HSNL/R are motor neurons that control egg-laying. The VC1 cell body (not shown) is situated more anteriorly. ReproTABLE 1: Lineal origin of the reproductive system. Tissues that make up the major components of the adult reproductive system: the somatic gonad, the germ line, and the egg-laying apparatus. aNumber of terminal cells per anterior or posterior arm (n,n) or entire gonad (n). bExcept for HSNL/R neurons, which are born in the embryo, reproductive tissues are generated post-embryonically from precursor cells present in the animal at hatching. cThe anchor cell is a transient cell that functions during development then fuses with the uterus in late L4. (DTC) Distal tip cell; (DG) distal gonad; (PG) proximal gonad; (Sp) spermatheca; (Sp-ut) spermathecal-uterine valve; VC1-6 and HSNL/R are motor neurons that control egg-laying. The somatic gonad is composed of the distal tip cell (DTC), gonadal sheath, spermatheca (sp), spermathecal-uterine (sp-ut) valve, and uterus (the uterus can also be considered part of the egg-laying apparatus). The adult germ line is organized in a distal-to-proximal manner, with distal corresponding to the region approaching the distal tip cell, and proximal corresponding to the nearest point at which embryos exit from the animal. Germ cells in the distal-most part of the gonad arm are mitotic and undifferentiated. As germ cells move proximally, they enter and pass through the stages of meiosis I prophase, reaching pachytene in the loop region, then progress further through meiosis in the proximal arm (ReproFIG 1). The egg-laying apparatus consists of the vulva, uterine and vulval muscles, left and right hermaphrodite specific neurons (HSNL/R), and VC1–6 neurons. The hermaphrodite is considered a specialized self-fertile female because the soma is female but the germ line first produces a fixed number of male gametes (sperm) before switching to the sole production of female gametes (oocytes) (L’Hernault, 1997; Schedl,1997). Hermaphrodites produce approximately 300 embryos by fertilization of oocytes with self-sperm (the process of self-fertilization). Fertilization is also achieved using male-derived sperm, transferred during copulation. In the proximal gonad, oocytes undergo maturation and are ovulated in single-file, assembly-line fashion into the sperm-containing spermatheca where they are fertilized (Singson, 2001). Fertilized eggs then move into the uterus. Activity of the egg-laying apparatus subsequently forces eggs out into the environment by passing them through a ventral opening called the vulva. 2 Lineal Origin of the Reproductive System Formation of the reproductive system spans the entire post-embryonic period. The reproductive system is formed by cells from several lineages (ReproTABLE 1; ReproFIG 2), including some that originate more posteriorly and must migrate considerable distances to be included in the developing system (e.g., the HSNs and uterine and vulval muscle precursors) (Sulston and Horvitz, 1977; Sulston et al., 1983). Not surprisingly, the organization of this complex system involves a hierarchy of temporally and spatially coordinated signaling events and cell–cell interactions (Sulston and White, 1980; Kimble, 1981; Sternberg and Horvitz, 1986; Sternberg, 1988; Thomas et al., 1990). The developing gonad itself serves as the primary organizer, promoting development of the vulva and uterus and guiding the precise positioning of sex muscle precursors (Kimble, 1981; Sternberg and Horvitz, 1986; Thomas et al., 1990; Newman et al., 1995). The vulva, in turn, acts as a secondary organizer for assembly of the egg-laying apparatus (Li and Chalfie, 1990; Thomas et al., 1990; Garriga et al., 1993; Chang et al., 1999; Shen and Bargmann, 2003; Shen et al., 2004). Finally, within the gonad itself, interactions between somatic tissues and the germ line have a critical role in promoting germ-line proliferation, polarity, progression of meiosis, ovulation, and gamete sexual identity (Kimble and White, 1981; Seydoux et al., 1990; McCarter et al., 1997; Pepper et al., 2003; Killian and Hubbard, 2004). Some maturation events occur remarkably late in reproductive system development. For instance, several anatomical changes are associated with ovulation. Spermatids, generated within the gonadal sheath, are pushed into the spermatheca by passage of the first oocyte. There they mature into spermatozoa (sperm) (L’Hernault ,1997). The sp-ut valve and uterus also undergo structural modification as a consequence of this first ovulation (J. White, unpubl.; D.H. Hall, unpubl.). ReproFIG 2: Precursor cells that give rise to the reproductive system. Schematic of an L1 hermaphrodite midbody region. Shown are the precursors (blast cells) that give rise to the reproductive tissues in the adult. Precursors are colored according to the adult tissues to which they will give rise. HSNL/R neurons are already generated at this time. The gonadal primordium containing Z1-Z4 straddles the ventral midline and is separated from other tissues by a gonadal basal lamina (orange). At hatching, assignment of P3, P4, P5, P6, P7, and P8 fates among the Pn cells has not yet occurred, so at this stage the cells are referred to as P3,4L, P3,4R, P5,6L, P5,6R, P7/8L, and P7/8R. (Based on Sulston and Horvitz, 1977; Kimble and Hirsh, 1979; Sulston et al., 1983; see also Epithelial System - Hypodermis.)
3 References Chang, C., Newman, A.P. and Sternberg, P.W. 1999. Reciprocal EGF signaling back to the uterus from the induced C. elegans vulva coordinates morphogenesis of epithelia. Curr. Biol. 9: 237-246. Article Garriga, G., Desai, C. and Horvitz, H.R. 1993. Cell interactions control the direction of outgrowth, branching and fasciculation of the HSN axons of Caenorhabditis elegans. Development 117: 1071-1087. Article Killian, D.J. and Hubbard, E.J. 2004. C. elegans pro-1 activity is required for soma/germline interactions that influence proliferation and differentiation in the germ line. Development 131: 1267-1278. Article Kimble, J.E. and White, J.G. 1981. On the control of germ cell development in Caenorhabditis elegans. Dev. Biol. 81: 208-219. Abstract Kimble, J. 1981. Alterations in cell lineage following laser ablation of cells in the somatic gonad of Caenorhabditis elegans. Dev. Biol. 87: 286-300. Abstract Kimble, J. and Hirsh, D. 1979. The postembryonic cell lineages of the hermaphrodite and male gonads in Caenorhabditis elegans. Dev. Biol. 70: 396-417. Article L'Hernault, S.W. 1997. Spermatogenesis. In C. elegans II (ed. D. L. Riddle et al.). Chap. 11. pp. 417-500. Cold Spring Harbor Laboratory Press, Cold Spring Harbor, New York. Article Li, C. and Chalfie, M.1990. Organogenesis in C. elegans: Positioning of neurons and muscles in the egg-laying system. Neuron 4: 681-695. Abstract McCarter, J., Bartlett, B., Dang, T. and Schedl, T. 1997. Soma-germ cell interactions in Caenorhabditis elegans: multiple events of hermaphrodite germline development require the somatic sheath and spermathecal lineages. Dev. Biol. 181: 121-143. Article Newman, A.P., White, J.G. and Sternberg, P.W. 1995. The Caenorhabditis elegans lin-12 gene mediates induction of ventral uterine specialization by the anchor cell. Development 121: 263-271. Article Pepper, A.S., Lo, T.W., Killian, D.J., Hall, D.H. and Hubbard, E.J. 2003. The establishment of Caenorhabditis elegans germline pattern is controlled by overlapping proximal and distal somatic gonad signals. Dev. Biol. 259: 336-350. Article Schedl, T. 1997. Developmental Genetics of the Germ Line. In C. elegans II (ed. D. L. Riddle et al.). chap. 10. pp. 417-500. Cold Spring Harbor Laboratory Press, Cold Spring Harbor, New York. Article Seydoux, G., Schedl, T. and Greenwald, I. 1990. Cell-cell interactions prevent a potential inductive interaction between soma and germline in C. elegans. Cell 61: 939-951. Abstract Shen, K. and Bargmann, C.I. 2003. The immunoglobulin superfamily protein SYG-1 determines the location of specific synapses in C. elegans. Cell 112: 619-630. Article Shen, K., Fetter, R.D. and Bargmann, C.I. 2004. Synaptic specificity is generated by the synaptic guidepost protein SYG-2 and its receptor, SYG-1. Cell 116: 869-881. Article Singson, A. 2001. Every sperm is sacred: fertilization in Caenorhabditis elegans. Dev. Biol. 230: 101-109. Article Sternberg, P.W. 1988. Lateral inhibition during vulval induction in Caenorhabditis elegans. Nature 335: 551-554. Abstract Sternberg, P.W. and Horvitz, H.R. 1986. Pattern formation during vulval development in C. elegans. Cell 44: 761-72. Abstract Sulston, J.E. and White, J.G. 1980. Regulation and cell autonomy during postembryonic development of C. elegans. Dev. Biol. 78: 577-597. Abstract Sulston, J. E. and Horvitz, H. R. 1977. Post-embryonic cell lineages of the nematode Caenorhabditis elegans. Dev. Biol. 56: 110-156. Article Sulston, J.E., Schierenberg, E., White, J.G. and Thomson, J.N. 1983.The embryonic cell lineage of the nematode Caenorhabditis elegans. Dev Biol. 100: 64-119. Article Thomas, J.H., Stern, M.J. and Horvitz, H.R. 1990. Cell interactions coordinate the development of the C. elegans egg-laying system. Cell 62: 1041-1052. Abstract
This chapter should be cited as: Lints, R. and Hall, D.H. 2009. Reproductive system, overview. In WormAtlas. doi:10.3908/wormatlas.1.21 Edited for the web by Laura A. Herndon. Last revision: June 16, 2010.

©Copyright 2025 WormAtlas (Cold Spring Harbor Laboratory Press) All Rights Reserved |